@@ -1,12 +1,11 @@
 import justpy as jp
-from typing import Union, List
 from .element import Element
 
 class Label(Element):
 
     def __init__(self,
                  text: str = '',
-                 typography: Union[str, List[str]] = []):
+                 ):
         """Label Element
 
         Displays some text.
@@ -14,13 +13,9 @@ class Label(Element):
         :param text: the content of the label
         """
 
-        if isinstance(typography, str):
-            typography = [typography]
-        classes = ' '.join('text-' + t for t in typography)
+        view = jp.Div(text=text)
 
-        view = jp.Div(text=text, classes=classes)
-
-        super().__init__(view, '')
+        super().__init__(view)
 
     @property
     def text(self):
